@@ -258,7 +258,7 @@ gst_bpm_detect_transform_ip (GstBaseTransform * trans, GstBuffer * in)
         bpm, (void *) NULL);
     gst_pad_push_event (trans->srcpad, gst_event_new_tag (tags));
 
-    GST_INFO_OBJECT (bpm_detect, "Detected BPM: %lf\n", bpm);
+    GST_INFO_OBJECT (bpm_detect, "Detected BPM: %lf", bpm);
     bpm_detect->bpm = bpm;
   }
 
