@@ -1,7 +1,7 @@
 /*
- * gstmpegtsdescriptor.c - 
+ * gstmpegtsdescriptor.c -
  * Copyright (C) 2013 Edward Hervey
- * 
+ *
  * Authors:
  *   Edward Hervey <edward@collabora.com>
  *
@@ -20,6 +20,10 @@
  * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
  * Boston, MA 02110-1301, USA.
  */
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <stdlib.h>
 #include <string.h>
 
@@ -40,7 +44,7 @@
  *
  * * Add common validation code for data presence and minimum/maximum expected
  *   size.
- * * Add parsing methods for the following descriptors that were previously 
+ * * Add parsing methods for the following descriptors that were previously
  *   handled in mpegtsbase:
  *   * GST_MTS_DESC_DVB_DATA_BROADCAST_ID
  *   * GST_MTS_DESC_DVB_CAROUSEL_IDENTIFIER
@@ -1285,7 +1289,7 @@ gst_mpegts_descriptor_parse_dvb_component (const GstMpegtsDescriptor
  *
  * Extracts the component tag from @descriptor.
  *
- * Returns: %TRUE if the parsing happended correctly, else %FALSE.
+ * Returns: %TRUE if the parsing happened correctly, else %FALSE.
  */
 gboolean
 gst_mpegts_descriptor_parse_dvb_stream_identifier (const GstMpegtsDescriptor
@@ -1930,7 +1934,7 @@ G_DEFINE_BOXED_TYPE (GstMpegtsDvbMultilingualComponentItem,
  * gst_mpegts_descriptor_parse_dvb_multilingual_component:
  * @descriptor: a %GST_MTS_DESC_DVB_MULTILINGUAL_COMPONENT
  * #GstMpegtsDescriptor
- * @component_tag: the component tag
+ * @component_tag: (out): the component tag
  * @component_description_items: (out) (transfer full) (element-type GstMpegtsDvbMultilingualComponentItem):
  * a #GstMpegtsDvbMultilingualComponentItem
  *
@@ -1983,8 +1987,8 @@ gst_mpegts_descriptor_parse_dvb_multilingual_component (const
  * @descriptor: a %GST_MTS_DESC_DVB_PRIVATE_DATA_SPECIFIER #GstMpegtsDescriptor
  * @private_data_specifier: (out): the private data specifier id
  * registered by http://www.dvbservices.com/
- * @private_data: (out) (transfer full)(allow-none): additional data or NULL
- * @length: (out) (allow-none): length of %private_data
+ * @private_data: (out) (transfer full) (allow-none) (array length=length): additional data or NULL
+ * @length: (out) (allow-none): length of @private_data
  *
  * Parses out the private data specifier from the @descriptor.
  *
@@ -2020,7 +2024,7 @@ gst_mpegts_descriptor_parse_dvb_private_data_specifier (const
  * @descriptor: a %GST_MTS_DESC_DVB_FREQUENCY_LIST #GstMpegtsDescriptor
  * @offset: (out): %FALSE in Hz, %TRUE in kHz
  * @list: (out) (transfer full) (element-type guint32): a list of all frequencies in Hz/kHz
- * depending on %offset
+ * depending on @offset
  *
  * Parses out a list of frequencies from the @descriptor.
  *
@@ -2190,8 +2194,8 @@ gst_mpegts_descriptor_parse_dvb_scrambling (const GstMpegtsDescriptor *
  * gst_mpegts_descriptor_parse_dvb_data_broadcast_id:
  * @descriptor: a %GST_MTS_DESC_DVB_DATA_BROADCAST_ID #GstMpegtsDescriptor
  * @data_broadcast_id: (out): the data broadcast id
- * @id_selector_bytes: (out) (transfer full): the selector bytes, if present
- * @len: (out): the length of #id_selector_bytes
+ * @id_selector_bytes: (out) (transfer full) (array length=len): the selector bytes, if present
+ * @len: (out): the length of @id_selector_bytes
  *
  * Parses out the data broadcast id from the @descriptor.
  *
