@@ -29,7 +29,7 @@
 #include "siren7.h"
 
 G_BEGIN_DECLS
-/* #define's don't like whitespacey bits */
+
 #define GST_TYPE_SIREN_ENC \
   (gst_siren_enc_get_type())
 #define GST_SIREN_ENC(obj) \
@@ -42,9 +42,9 @@ G_BEGIN_DECLS
   (G_TYPE_CHECK_INSTANCE_TYPE((obj),GST_TYPE_SIREN_ENC))
 #define GST_IS_SIREN_ENC_CLASS(obj) \
   (G_TYPE_CHECK_CLASS_TYPE((klass),GST_TYPE_SIREN_ENC))
+
 typedef struct _GstSirenEnc GstSirenEnc;
 typedef struct _GstSirenEncClass GstSirenEncClass;
-typedef struct _GstSirenEncPrivate GstSirenEncPrivate;
 
 struct _GstSirenEnc
 {
